---
layout: post
title:  "Welcome to slToo!"
date:   2021-02-06 14:46:53 +0100
categories: update
---

This is first entry on this homepage. Hopefully are relevant information will
eventually migrate hereto.

For starters see the current proposed [workflow]({{ site.baseurl }}{% link
workflow.md %}). Follow the link therein for a more technical description.

